## Summary

<!-- What does this PR do? One or two sentences. -->

## Changes

<!-- Bullet list of changes. -->

-

## Type of change

- [ ] Bug fix
- [ ] New feature
- [ ] Documentation
- [ ] Dependency update
- [ ] Refactor / cleanup

## Checklist

- [ ] Tests added or updated
- [ ] `uv run pytest` passes locally
- [ ] `uv run ruff check xanax/` passes
- [ ] `uv run mypy xanax/` passes
- [ ] Changelog updated (if user-facing change)

## Related issues

<!-- Closes #N, fixes #N, etc. -->
